@@ -2,7 +2,7 @@
 ###   "pbd*/src/Makevars.in" and "pbd*/src/Makevar.win"
 ### to find the default configurations from
 ###   "pbd*/etc${R_ARCH}/Makconf".
-get.conf <- function(arg, arch = '', package = "pbdMPI"){
+get.conf <- function(arg, arch = '', package = "pbdMPI", return = FALSE){
   file.name <- paste("./etc", arch, "/Makeconf", sep = "")
   file.path <- tools::file_path_as_absolute(
                  system.file(file.name, package = package))
@@ -10,7 +10,12 @@ get.conf <- function(arg, arch = '', package = "pbdMPI"){
 
   id <- grep(paste("^", arg, " = ", sep = ""), ret)
   if(length(id) > 0){
-    cat(gsub(paste("^", arg, " = (.*)", sep = ""), "\\1", ret[id[1]]))
+    ret <- gsub(paste("^", arg, " = (.*)", sep = ""), "\\1", ret[id[1]])
+    if(!return){
+      cat(ret)
+    } else{
+      return(invisible(ret))
+    }
   } else{
     stop("The arg is not found.")
   }
